==> haskell-cheapskate-0.1.1.2-182-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cheapskate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cheapskate
version:              0.1.1.2
visibility:           public
id:                   cheapskate-0.1.1.2-88KkhgJ5wTcDWCksnXnBR9
key:                  cheapskate-0.1.1.2-88KkhgJ5wTcDWCksnXnBR9
license:              BSD-3-Clause
copyright:            (C) 2012-2013 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             http://github.com/jgm/cheapskate
synopsis:             Experimental markdown processor.
description:
    This is an experimental Markdown processor in pure
    Haskell.  It aims to process Markdown efficiently and in
    the most forgiving possible way.  It is designed to deal
    with any input, including garbage, with linear
    performance.  Output is sanitized by default for
    protection against XSS attacks.

    Several markdown extensions are implemented, including
    fenced code blocks, significant list start numbers, and
    autolinked URLs.  See README.markdown for details.

category:             Text
abi:                  3dd065c17e71a241d9a026036778e70a
exposed:              True
exposed-modules:
    Cheapskate Cheapskate.Html Cheapskate.Parse Cheapskate.Types

hidden-modules:
    Cheapskate.Util Cheapskate.Inlines Cheapskate.ParserCombinators
    Paths_cheapskate

import-dirs:          /usr/lib/ghc-8.10.2/site-local/cheapskate-0.1.1.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/cheapskate-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/cheapskate-0.1.1.2
hs-libraries:         HScheapskate-0.1.1.2-88KkhgJ5wTcDWCksnXnBR9
depends:
    base-4.14.1.0 blaze-html-0.9.1.2-KH58zyIkQ2j6P8CxSvUYkL
    containers-0.6.2.1 data-default-0.7.1.1-72cggqozPVh3J5wCw4ajUU
    deepseq-1.4.4.0 mtl-2.2.2 syb-0.7.1-EJn6avnnYqseQTf54r0Yp
    text-1.2.3.2 uniplate-1.6.13-AnZoHmkJ7xsC3WYOvMVp6C
    xss-sanitize-0.3.6-Csf3Vv3wHbp3yt4uffBoHK

haddock-interfaces:   /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
haddock-html:         /usr/share/doc/haskell-cheapskate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cheapskate-0.1.1.2-183-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cheapskate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cheapskate
version:              0.1.1.2
visibility:           public
id:                   cheapskate-0.1.1.2-IxaHjsEnac565ArbJz4K4X
key:                  cheapskate-0.1.1.2-IxaHjsEnac565ArbJz4K4X
license:              BSD-3-Clause
copyright:            (C) 2012-2013 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             http://github.com/jgm/cheapskate
synopsis:             Experimental markdown processor.
description:
    This is an experimental Markdown processor in pure
    Haskell.  It aims to process Markdown efficiently and in
    the most forgiving possible way.  It is designed to deal
    with any input, including garbage, with linear
    performance.  Output is sanitized by default for
    protection against XSS attacks.

    Several markdown extensions are implemented, including
    fenced code blocks, significant list start numbers, and
    autolinked URLs.  See README.markdown for details.

category:             Text
abi:                  abb55c7e73ba8af9b2ff1c4b59486eca
exposed:              True
exposed-modules:
    Cheapskate Cheapskate.Html Cheapskate.Parse Cheapskate.Types

hidden-modules:
    Cheapskate.Util Cheapskate.Inlines Cheapskate.ParserCombinators
    Paths_cheapskate

import-dirs:          /usr/lib/ghc-8.10.2/site-local/cheapskate-0.1.1.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/cheapskate-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/cheapskate-0.1.1.2
hs-libraries:         HScheapskate-0.1.1.2-IxaHjsEnac565ArbJz4K4X
depends:
    base-4.14.1.0 blaze-html-0.9.1.2-KH58zyIkQ2j6P8CxSvUYkL
    containers-0.6.2.1 data-default-0.7.1.1-72cggqozPVh3J5wCw4ajUU
    deepseq-1.4.4.0 mtl-2.2.2 syb-0.7.1-EJn6avnnYqseQTf54r0Yp
    text-1.2.3.2 uniplate-1.6.13-AnZoHmkJ7xsC3WYOvMVp6C
    xss-sanitize-0.3.6-Csf3Vv3wHbp3yt4uffBoHK

haddock-interfaces:   /usr/share/doc/haskell-cheapskate/html/cheapskate.haddock
haddock-html:         /usr/share/doc/haskell-cheapskate/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
